@@ -13,19 +13,22 @@
 
    Copyright 2021, HSPyLib team
 """
+import concurrent
+from time import sleep
+from typing import List
 
-from addons.widman.widget import Widget
-
+from hspylib.addons.widman.widget import Widget
 from hspylib.core.enums.exit_code import ExitCode
 from hspylib.core.tools.commons import sysout
 from hspylib.modules.cli.icons.font_awesome.widget_icons import WidgetIcons
-from hspylib.modules.cli.tui.menu.menu_utils import MenuUtils
+from hspylib.modules.cli.keyboard import Keyboard
 
 
 class Widget_WIDGET_NAME_(Widget):
+    """HSPyLib to do something"""
     WIDGET_ICON = WidgetIcons.WIDGET
     WIDGET_NAME = "_WIDGET_NAME_"
-    TOOLTIP = "TODO usage."
+    TOOLTIP = "TODO Widget tooltip"
     USAGE = "Usage: _WIDGET_NAME_"
     VERSION = (0, 1, 0)
 
@@ -36,17 +39,23 @@ class Widget_WIDGET_NAME_(Widget):
             self.TOOLTIP,
             self.USAGE,
             self.VERSION)
+        self._exit_code = ExitCode.SUCCESS
 
-    def execute(self, *args) -> ExitCode:
-        # Include the widget's main http_code
-        sysout('')
-        sysout('My widget is running')
-        sysout('')
+    def execute(self, args: List[str] = None) -> ExitCode:
+        with concurrent.futures.ThreadPoolExecutor() as executor:
+            done = False
+            while not done and not Keyboard.kbhit():
+                future = executor.submit(self._do_something)
+                done = not future.result()
+                sleep(0.5)
 
-        MenuUtils.wait_enter()
-
-        return ExitCode.SUCCESS
+        return self._exit_code
 
     def cleanup(self) -> None:
         # If your widget requires any cleanup procedures
         pass
+
+    def _do_something(self) -> None:
+        sysout('')
+        sysout('My widget is running')
+        sysout('')
