@@ -1,6 +1,6 @@
 from PyQt5.QtCore import pyqtSlot, QAbstractAnimation, QEasingCurve, QParallelAnimationGroup, QPoint, \
     QPropertyAnimation, Qt
-from PyQt5.QtWidgets import QStackedWidget, QWidget
+from PyQt5.QtWidgets import QSizePolicy, QStackedWidget, QWidget
 
 
 class HStackedWidget(QStackedWidget):
@@ -28,6 +28,10 @@ class HStackedWidget(QStackedWidget):
     def set_wrap(self, wrap)  -> None:
         self._wrap = wrap
 
+    def addWidget(self, widget: QWidget) -> None:
+        widget.setSizePolicy(QSizePolicy.Ignored, QSizePolicy.Ignored)
+        super().addWidget(widget)
+
     @pyqtSlot()
     def slide_previous(self)  -> None:
         now = self.currentIndex()
